@@ -20,6 +20,7 @@
 #pragma once
 
 #include <adwaita.h>
+#define FMT_HEADER_ONLY
 #include <fmt/core.h>
 #include <fmt/format.h>
 #include <sigc++/sigc++.h>
@@ -80,6 +81,8 @@ void set_margin(Chart* self, const float& v);
 
 auto get_is_visible(Chart* self) -> bool;
 
+void set_dynamic_y_scale(Chart* self, const bool& v);
+
 auto create() -> Chart*;
 
 }  // namespace ui::chart
