@@ -50,7 +50,6 @@ class MultibandGate : public PluginBase {
   void update_probe_links() override;
 
   sigc::signal<void(const std::array<float, n_bands>)> reduction, envelope, curve, frequency_range;
-  sigc::signal<void(const std::array<double, n_bands>)> gating;
 
   float latency_port_value = 0.0F;
 
@@ -58,7 +57,6 @@ class MultibandGate : public PluginBase {
   std::array<float, n_bands> envelope_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
   std::array<float, n_bands> curve_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
   std::array<float, n_bands> reduction_port_array = {0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F, 0.0F};
-  std::array<double, n_bands> gating_array = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
 
  private:
   uint latency_n_frames = 0U;
@@ -86,6 +84,7 @@ class MultibandGate : public PluginBase {
     lv2_wrapper->bind_key_bool<sclc[n], band_lowcut_filter[n]>(settings);
     lv2_wrapper->bind_key_bool<schc[n], band_highcut_filter[n]>(settings);
 
+    lv2_wrapper->bind_key_enum<sscs[n], band_stereo_split_source[n]>(settings);
     lv2_wrapper->bind_key_enum<scs[n], band_sidechain_source[n]>(settings);
     lv2_wrapper->bind_key_enum<scm[n], band_sidechain_mode[n]>(settings);
 
