@@ -21,6 +21,7 @@
 
 #include <adwaita.h>
 #include "application.hpp"
+#include "config.h"
 #include "preset_type.hpp"
 #include "tags_resources.hpp"
 
@@ -36,6 +37,6 @@ G_END_DECLS
 
 auto create() -> PresetsMenu*;
 
-void setup(PresetsMenu* self, app::Application* application);
+void setup(PresetsMenu* self, app::Application* application, PresetType preset_type);
 
 }  // namespace ui::presets_menu
