@@ -27,7 +27,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  bool draw_bar_border, fill_bars, is_visible, rounded_corners;
+  bool draw_bar_border, fill_bars, is_visible, rounded_corners, dynamic_y_scale = true;
 
   int x_axis_height, n_x_decimals, n_y_decimals;
 
@@ -37,6 +37,8 @@ struct Data {
 
   double x_min_log, x_max_log;
 
+  double global_min_y = 0.0, global_max_y = 0.0;
+
   ChartType chart_type;
 
   ChartScale chart_scale;
@@ -172,7 +174,25 @@ void set_margin(Chart* self, const float& v) {
 }
 
 auto get_is_visible(Chart* self) -> bool {
-  return (self->data != nullptr) ? self->data->is_visible : false;
+  if (self == nullptr) {
+    return false;
+  }
+
+  if (self->data == nullptr) {
+    return false;
+  }
+
+  return self->data->is_visible;
+}
+
+void set_dynamic_y_scale(Chart* self, const bool& v) {
+  if (self->data == nullptr) {
+    return;
+  }
+
+  self->data->dynamic_y_scale = v;
+  self->data->global_min_y = 0.0;
+  self->data->global_max_y = 0.0;
 }
 
 void set_x_data(Chart* self, const std::vector<double>& x) {
@@ -217,8 +237,19 @@ void set_y_data(Chart* self, const std::vector<double>& y) {
 
   self->data->y_axis = y;
 
-  self->data->y_min = std::ranges::min(y);
-  self->data->y_max = std::ranges::max(y);
+  auto min_y = std::ranges::min(y);
+  auto max_y = std::ranges::max(y);
+
+  if (self->data->dynamic_y_scale) {
+    self->data->y_min = min_y;
+    self->data->y_max = max_y;
+  } else {
+    self->data->global_min_y = (min_y < self->data->global_min_y) ? min_y : self->data->global_min_y;
+    self->data->global_max_y = (max_y > self->data->global_max_y) ? max_y : self->data->global_max_y;
+
+    self->data->y_min = self->data->global_min_y;
+    self->data->y_max = self->data->global_max_y;
+  }
 
   if (std::fabs(self->data->y_max - self->data->y_min) < 0.00001) {
     std::ranges::fill(self->data->y_axis, 0.0);
@@ -237,8 +268,8 @@ void on_pointer_motion(GtkEventControllerMotion* controller, double xpos, double
   const auto x = xpos;
   const auto y = ypos;
 
-  const auto width = static_cast<double>(gtk_widget_get_allocated_width(GTK_WIDGET(self)));
-  const auto height = static_cast<double>(gtk_widget_get_allocated_height(GTK_WIDGET(self)));
+  const auto width = static_cast<double>(gtk_widget_get_width(GTK_WIDGET(self)));
+  const auto height = static_cast<double>(gtk_widget_get_height(GTK_WIDGET(self)));
 
   const auto usable_height = height - self->data->margin * height - self->data->x_axis_height;
 
