@@ -62,10 +62,14 @@ Compressor::Compressor(const std::string& tag,
 
   lv2_wrapper->bind_key_enum<"scs", "sidechain-source">(settings);
 
+  lv2_wrapper->bind_key_enum<"sscs", "stereo-split-source">(settings);
+
   lv2_wrapper->bind_key_enum<"shpm", "hpf-mode">(settings);
 
   lv2_wrapper->bind_key_enum<"slpm", "lpf-mode">(settings);
 
+  lv2_wrapper->bind_key_bool<"ssplit", "stereo-split">(settings);
+
   lv2_wrapper->bind_key_bool<"scl", "sidechain-listen">(settings);
 
   lv2_wrapper->bind_key_double<"at", "attack">(settings);
@@ -176,10 +180,17 @@ void Compressor::process(std::span<float>& left_in,
     get_peaks(left_in, right_in, left_out, right_out);
 
     if (send_notifications) {
-      reduction_port_value = lv2_wrapper->get_control_port_value("rlm");
-      sidechain_port_value = lv2_wrapper->get_control_port_value("slm");
-      curve_port_value = lv2_wrapper->get_control_port_value("clm");
-      envelope_port_value = lv2_wrapper->get_control_port_value("elm");
+      reduction_port_value =
+          0.5F * (lv2_wrapper->get_control_port_value("rlm_l") + lv2_wrapper->get_control_port_value("rlm_r"));
+
+      sidechain_port_value =
+          0.5F * (lv2_wrapper->get_control_port_value("slm_l") + lv2_wrapper->get_control_port_value("slm_r"));
+
+      curve_port_value =
+          0.5F * (lv2_wrapper->get_control_port_value("clm_l") + lv2_wrapper->get_control_port_value("clm_r"));
+
+      envelope_port_value =
+          0.5F * (lv2_wrapper->get_control_port_value("elm_l") + lv2_wrapper->get_control_port_value("elm_r"));
 
       reduction.emit(reduction_port_value);
       sidechain.emit(sidechain_port_value);
