@@ -59,12 +59,17 @@ void CompressorPreset::save(nlohmann::json& json) {
 
   json[section][instance_name]["boost-amount"] = g_settings_get_double(settings, "boost-amount");
 
+  json[section][instance_name]["stereo-split"] = g_settings_get_boolean(settings, "stereo-split") != 0;
+
   json[section][instance_name]["sidechain"]["type"] = util::gsettings_get_string(settings, "sidechain-type");
 
   json[section][instance_name]["sidechain"]["mode"] = util::gsettings_get_string(settings, "sidechain-mode");
 
   json[section][instance_name]["sidechain"]["source"] = util::gsettings_get_string(settings, "sidechain-source");
 
+  json[section][instance_name]["sidechain"]["stereo-split-source"] =
+      util::gsettings_get_string(settings, "stereo-split-source");
+
   json[section][instance_name]["sidechain"]["preamp"] = g_settings_get_double(settings, "sidechain-preamp");
 
   json[section][instance_name]["sidechain"]["reactivity"] = g_settings_get_double(settings, "sidechain-reactivity");
@@ -111,10 +116,15 @@ void CompressorPreset::load(const nlohmann::json& json) {
 
   update_key<double>(json.at(section).at(instance_name), settings, "boost-amount", "boost-amount");
 
+  update_key<bool>(json.at(section).at(instance_name), settings, "stereo-split", "stereo-split");
+
   update_key<gchar*>(json.at(section).at(instance_name).at("sidechain"), settings, "sidechain-type", "type");
 
   update_key<gchar*>(json.at(section).at(instance_name).at("sidechain"), settings, "sidechain-mode", "mode");
 
+  update_key<gchar*>(json.at(section).at(instance_name).at("sidechain"), settings, "stereo-split-source",
+                     "stereo-split-source");
+
   update_key<gchar*>(json.at(section).at(instance_name).at("sidechain"), settings, "sidechain-source", "source");
 
   update_key<double>(json.at(section).at(instance_name).at("sidechain"), settings, "sidechain-preamp", "preamp");
