@@ -122,7 +122,7 @@ void plot_fft(ConvolverBox* self) {
 }
 
 void plot_waveform(ConvolverBox* self) {
-  if (self->data->time_axis.empty() || self->data->left_spectrum.empty() || self->data->right_spectrum.empty()) {
+  if (self->data->time_axis.empty() || self->data->left_mag.empty() || self->data->right_mag.empty()) {
     return;
   }
 
@@ -284,9 +284,9 @@ void get_irs_spectrum(ConvolverBox* self, const int& rate) {
 
   std::copy(log_axis.begin(), log_axis.end(), freq_axis.begin());
 
-  self->data->freq_axis = freq_axis;
   self->data->left_spectrum = interpolate(self->data->freq_axis, self->data->left_spectrum, freq_axis);
   self->data->right_spectrum = interpolate(self->data->freq_axis, self->data->right_spectrum, freq_axis);
+  self->data->freq_axis = freq_axis;  // it has to be after the two previous lines
 
   // find min and max values
 
@@ -304,6 +304,10 @@ void get_irs_spectrum(ConvolverBox* self, const int& rate) {
   }
 
   util::idle_add([=]() {
+    if (self == nullptr) {
+      return;
+    }
+
     if (!ui::chart::get_is_visible(self->chart)) {
       return;
     }
@@ -338,6 +342,10 @@ void get_irs_info(ConvolverBox* self) {
     // warning the user that there is a problem
 
     util::idle_add([=]() {
+      if (self == nullptr) {
+        return;
+      }
+
       if (!ui::chart::get_is_visible(self->chart)) {
         return;
       }
@@ -383,9 +391,9 @@ void get_irs_info(ConvolverBox* self) {
 
   std::copy(x_linear.begin(), x_linear.end(), x_axis.begin());
 
-  self->data->time_axis = x_axis;
   self->data->left_mag = interpolate(self->data->time_axis, self->data->left_mag, x_axis);
   self->data->right_mag = interpolate(self->data->time_axis, self->data->right_mag, x_axis);
+  self->data->time_axis = x_axis;  // it has to be after the two previous lines
 
   self->data->time_axis.shrink_to_fit();
   self->data->left_mag.shrink_to_fit();
@@ -412,6 +420,10 @@ void get_irs_info(ConvolverBox* self) {
   auto n_samples = kernel_L.size();
 
   util::idle_add([=]() {
+    if (self == nullptr) {
+      return;
+    }
+
     if (!ui::chart::get_is_visible(self->chart)) {
       return;
     }
