@@ -119,6 +119,9 @@ void setup_spectrum(EffectsBox* self) {
 
   ui::chart::set_fill_bars(self->spectrum_chart, g_settings_get_boolean(self->settings_spectrum, "fill") != 0);
 
+  ui::chart::set_dynamic_y_scale(self->spectrum_chart,
+                                 g_settings_get_boolean(self->settings_spectrum, "dynamic-y-scale") != 0);
+
   ui::chart::set_rounded_corners(self->spectrum_chart,
                                  g_settings_get_boolean(self->settings_spectrum, "rounded-corners") != 0);
 
@@ -172,6 +175,13 @@ void setup_spectrum(EffectsBox* self) {
       }),
       self));
 
+  self->data->gconnections_spectrum.push_back(g_signal_connect(
+      self->settings_spectrum, "changed::dynamic-y-scale",
+      G_CALLBACK(+[](GSettings* settings, char* key, EffectsBox* self) {
+        ui::chart::set_dynamic_y_scale(self->spectrum_chart, g_settings_get_boolean(self->settings_spectrum, key) != 0);
+      }),
+      self));
+
   self->data->gconnections_spectrum.push_back(g_signal_connect(
       self->settings_spectrum, "changed::rounded-corners",
       G_CALLBACK(+[](GSettings* settings, char* key, EffectsBox* self) {
@@ -234,6 +244,7 @@ void setup_spectrum(EffectsBox* self) {
                        }),
                        self));
 }
+
 void stack_visible_child_changed(EffectsBox* self, GParamSpec* pspec, GtkWidget* stack) {
   const auto* name = adw_view_stack_get_visible_child_name(ADW_VIEW_STACK(stack));
 
@@ -351,6 +362,10 @@ void setup(EffectsBox* self, app::Application* application, PipelineType pipelin
 
   self->data->connections.push_back(
       self->data->effects_base->spectrum->power.connect([=](uint rate, uint n_bands, std::vector<double> magnitudes) {
+        if (self == nullptr) {
+          return;
+        }
+
         if (!ui::chart::get_is_visible(self->spectrum_chart)) {
           return;
         }
