@@ -23,20 +23,32 @@ Filter::Filter(const std::string& tag,
                const std::string& schema,
                const std::string& schema_path,
                PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::filter, tags::plugin_package::calf, schema, schema_path, pipe_manager) {
-  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://calf.sourceforge.net/plugins/Filter");
+    : PluginBase(tag, tags::plugin_name::filter, tags::plugin_package::lsp, schema, schema_path, pipe_manager) {
+  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/filter_stereo");
 
   package_installed = lv2_wrapper->found_plugin;
 
   if (!package_installed) {
-    util::debug(log_tag + "http://calf.sourceforge.net/plugins/Filter is not installed");
+    util::debug(log_tag + "http://lsp-plug.in/plugins/lv2/sc_gate_stereo is not installed");
   }
 
-  lv2_wrapper->bind_key_double<"freq", "frequency">(settings);
+  lv2_wrapper->bind_key_double<"f", "frequency">(settings);
 
-  lv2_wrapper->bind_key_double_db<"res", "resonance">(settings);
+  lv2_wrapper->bind_key_double<"w", "width">(settings);
 
-  lv2_wrapper->bind_key_enum<"mode", "mode">(settings);
+  lv2_wrapper->bind_key_double<"q", "quality">(settings);
+
+  lv2_wrapper->bind_key_double<"bal", "balance">(settings);
+
+  lv2_wrapper->bind_key_double_db<"g", "gain">(settings);
+
+  lv2_wrapper->bind_key_enum<"ft", "type">(settings);
+
+  lv2_wrapper->bind_key_enum<"fm", "mode">(settings);
+
+  lv2_wrapper->bind_key_enum<"mode", "equal-mode">(settings);
+
+  lv2_wrapper->bind_key_enum<"s", "slope">(settings);
 
   setup_input_output_gain();
 
