@@ -44,9 +44,11 @@ struct _FilterBox {
   GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
       *plugin_credit;
 
-  GtkDropDown* mode;
+  GtkDropDown *mode, *equalizer_mode, *type, *slope;
 
-  GtkSpinButton *frequency, *resonance, *inertia;
+  GtkSpinButton *frequency, *width, *gain, *quality, *balance;
+
+  GtkToggleButton* show_native_ui;
 
   GSettings* settings;
 
@@ -60,6 +62,14 @@ void on_reset(FilterBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings);
 }
 
+void on_show_native_window(FilterBox* self, GtkToggleButton* btn) {
+  if (gtk_toggle_button_get_active(btn) != 0) {
+    self->data->filter->show_native_ui();
+  } else {
+    self->data->filter->close_native_ui();
+  }
+}
+
 void setup(FilterBox* self, std::shared_ptr<Filter> filter, const std::string& schema_path) {
   auto serial = get_new_filter_serial();
 
@@ -104,13 +114,27 @@ void setup(FilterBox* self, std::shared_ptr<Filter> filter, const std::string& s
   g_settings_bind(self->settings, "frequency", gtk_spin_button_get_adjustment(self->frequency), "value",
                   G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "resonance", gtk_spin_button_get_adjustment(self->resonance), "value",
+  g_settings_bind(self->settings, "width", gtk_spin_button_get_adjustment(self->width), "value",
                   G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "inertia", gtk_spin_button_get_adjustment(self->inertia), "value",
+  g_settings_bind(self->settings, "gain", gtk_spin_button_get_adjustment(self->gain), "value", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(self->settings, "quality", gtk_spin_button_get_adjustment(self->quality), "value",
                   G_SETTINGS_BIND_DEFAULT);
 
+  g_settings_bind(self->settings, "balance", gtk_spin_button_get_adjustment(self->balance), "value",
+                  G_SETTINGS_BIND_DEFAULT);
+
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "type", self->type);
+
   ui::gsettings_bind_enum_to_combo_widget(self->settings, "mode", self->mode);
+
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "equal-mode", self->equalizer_mode);
+
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "slope", self->slope);
+
+  g_settings_bind(ui::get_global_app_settings(), "show-native-plugin-ui", self->show_native_ui, "visible",
+                  G_SETTINGS_BIND_DEFAULT);
 }
 
 void dispose(GObject* object) {
@@ -118,6 +142,8 @@ void dispose(GObject* object) {
 
   self->data->filter->set_post_messages(false);
 
+  self->data->filter->close_native_ui();
+
   set_ignore_filter_idle_add(self->data->serial, true);
 
   for (auto& c : self->data->connections) {
@@ -169,12 +195,20 @@ void filter_box_class_init(FilterBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, FilterBox, output_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, FilterBox, plugin_credit);
 
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, type);
   gtk_widget_class_bind_template_child(widget_class, FilterBox, mode);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, equalizer_mode);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, slope);
   gtk_widget_class_bind_template_child(widget_class, FilterBox, frequency);
-  gtk_widget_class_bind_template_child(widget_class, FilterBox, resonance);
-  gtk_widget_class_bind_template_child(widget_class, FilterBox, inertia);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, width);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, gain);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, quality);
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, balance);
+
+  gtk_widget_class_bind_template_child(widget_class, FilterBox, show_native_ui);
 
   gtk_widget_class_bind_template_callback(widget_class, on_reset);
+  gtk_widget_class_bind_template_callback(widget_class, on_show_native_window);
 }
 
 void filter_box_init(FilterBox* self) {
@@ -185,8 +219,9 @@ void filter_box_init(FilterBox* self) {
   prepare_scales<"dB">(self->input_gain, self->output_gain);
 
   prepare_spinbuttons<"Hz">(self->frequency);
-  prepare_spinbuttons<"dB">(self->resonance);
-  prepare_spinbuttons<"ms">(self->inertia);
+  prepare_spinbuttons<"dB">(self->gain);
+  prepare_spinbuttons<"">(self->width, self->quality);
+  prepare_spinbuttons<"%">(self->balance);
 }
 
 auto create() -> FilterBox* {
