@@ -35,7 +35,7 @@ struct _MultibandGateBandBox {
 
   GtkToggleButton *bypass, *mute, *solo, *external_sidechain, *hysteresis;
 
-  GtkLabel *end_label, *gain_label, *envelope_label, *curve_label, *gating_label;
+  GtkLabel *end_label, *gain_label, *envelope_label, *curve_label;
 
   GtkSpinButton *split_frequency, *lowcut_filter_frequency, *highcut_filter_frequency, *attack_time, *release_time,
       *hysteresis_threshold, *hysteresis_zone, *curve_threshold, *curve_zone, *reduction, *makeup, *sidechain_preamp,
@@ -43,12 +43,10 @@ struct _MultibandGateBandBox {
 
   GtkCheckButton *lowcut_filter, *highcut_filter;
 
-  GtkDropDown *sidechain_mode, *sidechain_source;
+  GtkDropDown *sidechain_mode, *sidechain_source, *stereo_split_source;
 
   GtkBox* split_frequency_box;
 
-  GtkLevelBar* gating;
-
   GSettings* settings;
 
   Data* data;
@@ -102,22 +100,9 @@ void set_gain_label(MultibandGateBandBox* self, const float& value) {
     return;
   }
 
-  gtk_label_set_text(self->gating_label, fmt::format("{0:.0Lf}", util::linear_to_db(value)).c_str());
   gtk_label_set_text(self->gain_label, fmt::format("{0:.0f}", util::linear_to_db(value)).c_str());
 }
 
-void set_gating_levelbar(MultibandGateBandBox* self, const float& value) {
-  if (!GTK_IS_WIDGET(self)) {
-    return;
-  }
-
-  if (!GTK_IS_LEVEL_BAR(self->gating)) {
-    return;
-  }
-
-  gtk_level_bar_set_value(self->gating, value);
-}
-
 void setup(MultibandGateBandBox* self, GSettings* settings, int index) {
   self->data->index = index;
   self->settings = settings;
@@ -162,6 +147,9 @@ void setup(MultibandGateBandBox* self, GSettings* settings, int index) {
 
   ui::gsettings_bind_enum_to_combo_widget(self->settings, band_sidechain_source[index].data(), self->sidechain_source);
 
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, band_stereo_split_source[index].data(),
+                                          self->stereo_split_source);
+
   g_settings_bind(settings, band_lowcut_filter_frequency[index].data(),
                   gtk_spin_button_get_adjustment(self->lowcut_filter_frequency), "value", G_SETTINGS_BIND_DEFAULT);
 
@@ -202,6 +190,13 @@ void setup(MultibandGateBandBox* self, GSettings* settings, int index) {
 
   g_settings_bind(settings, band_sidechain_lookahead[index].data(),
                   gtk_spin_button_get_adjustment(self->sidechain_lookahead), "value", G_SETTINGS_BIND_DEFAULT);
+
+  // bind source dropdowns sensitive property to split-stereo gsettings boolean
+
+  g_settings_bind(self->settings, "stereo-split", self->sidechain_source, "sensitive",
+                  static_cast<GSettingsBindFlags>(G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_INVERT_BOOLEAN));
+
+  g_settings_bind(self->settings, "stereo-split", self->stereo_split_source, "sensitive", G_SETTINGS_BIND_DEFAULT);
 }
 
 void dispose(GObject* object) {
@@ -243,8 +238,6 @@ void multiband_gate_band_box_class_init(MultibandGateBandBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, external_sidechain);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, end_label);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, gain_label);
-  gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, gating);
-  gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, gating_label);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, envelope_label);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, curve_label);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, split_frequency);
@@ -267,6 +260,7 @@ void multiband_gate_band_box_class_init(MultibandGateBandBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, sidechain_lookahead);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, sidechain_mode);
   gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, sidechain_source);
+  gtk_widget_class_bind_template_child(widget_class, MultibandGateBandBox, stereo_split_source);
 }
 
 void multiband_gate_band_box_init(MultibandGateBandBox* self) {
