@@ -24,10 +24,17 @@ RNNoise::RNNoise(const std::string& tag,
                  const std::string& schema_path,
                  PipeManager* pipe_manager)
     : PluginBase(tag, tags::plugin_name::rnnoise, tags::plugin_package::rnnoise, schema, schema_path, pipe_manager),
+      enable_vad(g_settings_get_boolean(settings, "enable-vad")),
+      vad_thres(g_settings_get_double(settings, "vad-thres") / 100.0F),
       data_L(0),
       data_R(0) {
   data_L.reserve(blocksize);
   data_R.reserve(blocksize);
+  data_tmp.reserve(blocksize);
+
+  const auto key_v = g_settings_get_double(settings, "wet");
+
+  wet_ratio = (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
 
   gconnections.push_back(g_signal_connect(settings, "changed::model-path",
                                           G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
@@ -58,6 +65,38 @@ RNNoise::RNNoise(const std::string& tag,
 
 #ifdef ENABLE_RNNOISE
 
+  init_release();
+
+  gconnections.push_back(g_signal_connect(settings, "changed::enable-vad",
+                                          G_CALLBACK(+[](GSettings* settings, char* key, RNNoise* self) {
+                                            self->enable_vad = g_settings_get_boolean(settings, key);
+                                          }),
+                                          this));
+
+  g_signal_connect(settings, "changed::vad-thres", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                     auto self = static_cast<RNNoise*>(user_data);
+
+                     self->vad_thres = static_cast<float>(g_settings_get_double(settings, key)) / 100.0F;
+                   }),
+                   this);
+
+  g_signal_connect(settings, "changed::wet", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                     auto self = static_cast<RNNoise*>(user_data);
+
+                     const auto key_v = g_settings_get_double(settings, key);
+
+                     self->wet_ratio =
+                         (key_v <= util::minimum_db_d_level) ? 0.0F : static_cast<float>(util::db_to_linear(key_v));
+                   }),
+                   this);
+
+  g_signal_connect(settings, "changed::release", G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                     auto self = static_cast<RNNoise*>(user_data);
+
+                     self->init_release();
+                   }),
+                   this);
+
   auto* m = get_model_from_file();
 
   model = m;
@@ -65,9 +104,16 @@ RNNoise::RNNoise(const std::string& tag,
   state_left = rnnoise_create(model);
   state_right = rnnoise_create(model);
 
+  vad_prob_left = 1.0F;
+  vad_prob_right = 1.0F;
+  vad_grace_left = release;
+  vad_grace_right = release;
+
   rnnoise_ready = true;
 #else
   util::warning("The RNNoise library was not available at compilation time. The noise reduction filter won't work");
+
+  enable_vad = false;
 #endif
 }
 
@@ -294,3 +340,21 @@ void RNNoise::free_rnnoise() {
 auto RNNoise::get_latency_seconds() -> float {
   return latency_value;
 }
+
+void RNNoise::init_release() {
+#ifdef ENABLE_RNNOISE
+
+  const auto key_v = g_settings_get_double(settings, "release");
+
+  const auto rate = static_cast<double>(rnnoise_rate);
+
+  const auto bs = static_cast<double>(blocksize);
+
+  // std::lrint returns a long type
+  const auto release = static_cast<int>(std::lrint(rate * key_v / 1000.0 / bs));
+
+  vad_grace_left = release;
+  vad_grace_right = release;
+
+#endif
+}
