@@ -56,11 +56,15 @@ struct _RNNoiseBox {
 
   GtkScale *input_gain, *output_gain;
 
+  GtkSpinButton *vad_thres, *wet, *release;
+
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
   GtkLabel *active_model_name, *model_active_state, *model_error_state, *input_level_left_label,
       *input_level_right_label, *output_level_left_label, *output_level_right_label, *plugin_credit;
 
+  GtkSwitch* enable_vad;
+
   GtkListView* listview;
 
   GtkStringList* string_list;
@@ -250,7 +254,8 @@ void setup(RNNoiseBox* self,
 
   gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->rnnoise->package).c_str());
 
-  gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
+  gsettings_bind_widgets<"input-gain", "output-gain", "enable-vad", "vad-thres", "wet", "release">(
+      self->settings, self->input_gain, self->output_gain, self->enable_vad, self->vad_thres, self->wet, self->release);
 
   g_settings_bind_with_mapping(
       self->settings, "model-path", self->selection_model, "selected", G_SETTINGS_BIND_DEFAULT,
@@ -369,6 +374,11 @@ void rnnoise_box_class_init(RNNoiseBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, output_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, plugin_credit);
 
+  gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, enable_vad);
+  gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, vad_thres);
+  gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, wet);
+  gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, release);
+
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, string_list);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, selection_model);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, listview);
@@ -390,6 +400,13 @@ void rnnoise_box_init(RNNoiseBox* self) {
 
   prepare_scales<"dB">(self->input_gain, self->output_gain);
 
+  prepare_spinbutton<"ms">(self->release);
+
+  prepare_spinbutton<"%">(self->vad_thres);
+
+  // The following spinbuttons can assume -inf
+  prepare_spinbuttons<"dB", false>(self->wet);
+
   // model dir
 
   if (!std::filesystem::is_directory(model_dir)) {
