@@ -19,9 +19,6 @@
 
 #include "util.hpp"
 
-#include <regex>
-#include <utility>
-
 namespace util {
 
 auto prepare_debug_message(const std::string& message, source_location location) -> std::string {
@@ -200,6 +197,8 @@ auto gsettings_get_string(GSettings* settings, const char* key) -> std::string {
   return output;
 }
 
+// The following is not used and it was made only for reference. May be removed in the future.
+// GIO recommends to not use g_settings_schema_key_get_range in "normal programs".
 auto gsettings_get_range(GSettings* settings, const char* key) -> std::pair<std::string, std::string> {
   GSettingsSchema* schema = nullptr;
   const gchar* type = nullptr;
@@ -401,7 +400,7 @@ auto compare_versions(const std::string& v0, const std::string& v1) -> int {
     int patch = -1;
   };
 
-  static const auto re_semver = std::regex(R"(^(\d++)\.?+(\d++)?+\.?+(\d++)?+)");
+  static const auto re_semver = std::regex(R"(^(\d+)\.?(\d+)?\.?(\d+)?)");
 
   std::array<SemVer, 2> sv{};
   std::array<std::string, 2> v{v0, v1};
